diff --git a/asdf.asd b/asdf.asd
index 59025896740ca0655fed60680fc163f9cab9f46d..1980bcc57d7111003c7ff74f98efa1c038ad8a50 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.26.29" ;; to be automatically updated by bin/bump-revision
+  :version "2.26.30" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")))
diff --git a/asdf.lisp b/asdf.lisp
index 7219bc1f7703900ea6d98964ddcb0c6560dd6bb3..b2a7c48070d6cec6eef2d073e39c30b07c089769 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
 ;;; This is ASDF 2.26.29: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -118,7 +118,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.26.29")
+         (asdf-version "2.26.30")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -4726,7 +4726,8 @@ with a different configuration, so the configuration would be re-read then."
 ;;;
 
 (defclass compiled-file (child-component)
-  ((type :initform #-(or ecl mkcl) (fasl-type) #+(or ecl mkcl) "fasb")))
+  ((type :initform #-(or ecl mkcl) (fasl-type) #+(or ecl mkcl) "fasb"
+         :reader source-file-type)))
 
 (defmethod trivial-system-p ((s parent-component))
   (every #'(lambda (c) (typep c 'compiled-file)) (component-children s)))
@@ -1,5 +1,5 @@
 ;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.26.29: Another System Definition Facility.
+;;; This is ASDF 2.26.30: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: